/****************************************************************************
** QgsVectorLayer meta object code from reading C++ file 'qgsvectorlayer.h'
**
** Created: Fri Nov 4 14:08:55 2005
**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#undef QT_NO_COMPAT
#include "qgsvectorlayer.h"
#include <qmetaobject.h>
#include <qapplication.h>

#include <private/qucomextra_p.h>
#if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
#error "This file was generated using the moc from 3.3.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

const char *QgsVectorLayer::className() const
{
    return "QgsVectorLayer";
}

QMetaObject *QgsVectorLayer::metaObj = 0;
static QMetaObjectCleanUp cleanUp_QgsVectorLayer( "QgsVectorLayer", &QgsVectorLayer::staticMetaObject );

#ifndef QT_NO_TRANSLATION
QString QgsVectorLayer::tr( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsVectorLayer", s, c, QApplication::DefaultCodec );
    else
	return QString::fromLatin1( s );
}
#ifndef QT_NO_TRANSLATION_UTF8
QString QgsVectorLayer::trUtf8( const char *s, const char *c )
{
    if ( qApp )
	return qApp->translate( "QgsVectorLayer", s, c, QApplication::UnicodeUTF8 );
    else
	return QString::fromUtf8( s );
}
#endif // QT_NO_TRANSLATION_UTF8

#endif // QT_NO_TRANSLATION

QMetaObject* QgsVectorLayer::staticMetaObject()
{
    if ( metaObj )
	return metaObj;
    QMetaObject* parentObject = QgsMapLayer::staticMetaObject();
    static const QUParameter param_slot_0[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_0 = {"inOverview", 1, param_slot_0 };
    static const QUMethod slot_1 = {"invalidateTableDisplay", 0, 0 };
    static const QUParameter param_slot_2[] = {
	{ "number", &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_2 = {"select", 1, param_slot_2 };
    static const QUMethod slot_3 = {"removeSelection", 0, 0 };
    static const QUMethod slot_4 = {"triggerRepaint", 0, 0 };
    static const QUMethod slot_5 = {"showLayerProperties", 0, 0 };
    static const QUParameter param_slot_6[] = {
	{ 0, &static_QUType_ptr, "QgsRenderer", QUParameter::Out }
    };
    static const QUMethod slot_6 = {"renderer", 1, param_slot_6 };
    static const QUParameter param_slot_7[] = {
	{ 0, &static_QUType_ptr, "QDialog", QUParameter::Out }
    };
    static const QUMethod slot_7 = {"rendererDialog", 1, param_slot_7 };
    static const QUParameter param_slot_8[] = {
	{ "r", &static_QUType_ptr, "QgsRenderer", QUParameter::In }
    };
    static const QUMethod slot_8 = {"setRenderer", 1, param_slot_8 };
    static const QUParameter param_slot_9[] = {
	{ "dialog", &static_QUType_ptr, "QDialog", QUParameter::In }
    };
    static const QUMethod slot_9 = {"setRendererDialog", 1, param_slot_9 };
    static const QUParameter param_slot_10[] = {
	{ "properties", &static_QUType_ptr, "QgsDlgVectorLayerProperties", QUParameter::In }
    };
    static const QUMethod slot_10 = {"setLayerProperties", 1, param_slot_10 };
    static const QUMethod slot_11 = {"vectorType", 0, 0 };
    static const QUParameter param_slot_12[] = {
	{ 0, &static_QUType_ptr, "QgsDlgVectorLayerProperties", QUParameter::Out }
    };
    static const QUMethod slot_12 = {"propertiesDialog", 1, param_slot_12 };
    static const QUParameter param_slot_13[] = {
	{ 0, &static_QUType_ptr, "QPopupMenu", QUParameter::Out }
    };
    static const QUMethod slot_13 = {"contextMenu", 1, param_slot_13 };
    static const QUMethod slot_14 = {"bBoxOfSelected", 0, 0 };
    static const QUParameter param_slot_15[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::Out }
    };
    static const QUMethod slot_15 = {"providerType", 1, param_slot_15 };
    static const QUParameter param_slot_16[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out }
    };
    static const QUMethod slot_16 = {"isValid", 1, param_slot_16 };
    static const QUParameter param_slot_17[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out },
	{ "layer_node", &static_QUType_ptr, "QDomNode", QUParameter::InOut }
    };
    static const QUMethod slot_17 = {"readXML_", 2, param_slot_17 };
    static const QUParameter param_slot_18[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out },
	{ "layer_node", &static_QUType_ptr, "QDomNode", QUParameter::InOut },
	{ "doc", &static_QUType_ptr, "QDomDocument", QUParameter::InOut }
    };
    static const QUMethod slot_18 = {"writeXML_", 3, param_slot_18 };
    static const QUParameter param_slot_19[] = {
	{ 0, &static_QUType_ptr, "QgsFeature", QUParameter::Out }
    };
    static const QUMethod slot_19 = {"getFirstFeature", 1, param_slot_19 };
    static const QUParameter param_slot_20[] = {
	{ 0, &static_QUType_ptr, "QgsFeature", QUParameter::Out },
	{ "fetchAttributes", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_20 = {"getFirstFeature", 2, param_slot_20 };
    static const QUParameter param_slot_21[] = {
	{ 0, &static_QUType_ptr, "QgsFeature", QUParameter::Out }
    };
    static const QUMethod slot_21 = {"getNextFeature", 1, param_slot_21 };
    static const QUParameter param_slot_22[] = {
	{ 0, &static_QUType_ptr, "QgsFeature", QUParameter::Out },
	{ "fetchAttributes", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_22 = {"getNextFeature", 2, param_slot_22 };
    static const QUParameter param_slot_23[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out },
	{ "feature", &static_QUType_ptr, "QgsFeature", QUParameter::InOut }
    };
    static const QUMethod slot_23 = {"getNextFeature", 2, param_slot_23 };
    static const QUParameter param_slot_24[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out },
	{ "feature", &static_QUType_ptr, "QgsFeature", QUParameter::InOut },
	{ "fetchAttributes", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_24 = {"getNextFeature", 3, param_slot_24 };
    static const QUMethod slot_25 = {"featureCount", 0, 0 };
    static const QUMethod slot_26 = {"updateFeatureCount", 0, 0 };
    static const QUMethod slot_27 = {"updateExtents", 0, 0 };
    static const QUParameter param_slot_28[] = {
	{ "subset", &static_QUType_QString, 0, QUParameter::In }
    };
    static const QUMethod slot_28 = {"setSubsetString", 1, param_slot_28 };
    static const QUParameter param_slot_29[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::Out }
    };
    static const QUMethod slot_29 = {"subsetString", 1, param_slot_29 };
    static const QUParameter param_slot_30[] = {
	{ 0, &static_QUType_int, 0, QUParameter::Out }
    };
    static const QUMethod slot_30 = {"fieldCount", 1, param_slot_30 };
    static const QUMethod slot_31 = {"fields", 0, 0 };
    static const QUParameter param_slot_32[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out },
	{ "f", &static_QUType_ptr, "QgsFeature", QUParameter::In }
    };
    static const QUMethod slot_32 = {"addFeature", 2, param_slot_32 };
    static const QUParameter param_slot_33[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out }
    };
    static const QUMethod slot_33 = {"deleteSelectedFeatures", 1, param_slot_33 };
    static const QUParameter param_slot_34[] = {
	{ 0, &static_QUType_QString, 0, QUParameter::Out },
	{ "attr", &static_QUType_QString, 0, QUParameter::In },
	{ "f", &static_QUType_ptr, "QgsFeature", QUParameter::In }
    };
    static const QUMethod slot_34 = {"getDefaultValue", 3, param_slot_34 };
    static const QUParameter param_slot_35[] = {
	{ "on", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod slot_35 = {"setLabelOn", 1, param_slot_35 };
    static const QUParameter param_slot_36[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out }
    };
    static const QUMethod slot_36 = {"labelOn", 1, param_slot_36 };
    static const QUParameter param_slot_37[] = {
	{ 0, &static_QUType_int, 0, QUParameter::Out }
    };
    static const QUMethod slot_37 = {"minimumScale", 1, param_slot_37 };
    static const QUParameter param_slot_38[] = {
	{ 0, &static_QUType_int, 0, QUParameter::Out }
    };
    static const QUMethod slot_38 = {"maximumScale", 1, param_slot_38 };
    static const QUParameter param_slot_39[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out }
    };
    static const QUMethod slot_39 = {"scaleDependentRender", 1, param_slot_39 };
    static const QUParameter param_slot_40[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out }
    };
    static const QUMethod slot_40 = {"isEditable", 1, param_slot_40 };
    static const QUParameter param_slot_41[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out }
    };
    static const QUMethod slot_41 = {"isModified", 1, param_slot_41 };
    static const QUMethod slot_42 = {"saveAsShapefile", 0, 0 };
    static const QUParameter param_slot_43[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out },
	{ "point", &static_QUType_ptr, "QgsPoint", QUParameter::InOut },
	{ "tolerance", &static_QUType_double, 0, QUParameter::In }
    };
    static const QUMethod slot_43 = {"snapPoint", 3, param_slot_43 };
    static const QUParameter param_slot_44[] = {
	{ 0, &static_QUType_bool, 0, QUParameter::Out },
	{ "deleted", &static_QUType_ptr, "std::set<QString>", QUParameter::In },
	{ "added", &static_QUType_ptr, "std::map<QString,QString>", QUParameter::In },
	{ "changed", &static_QUType_ptr, "std::map<int,std::map<QString,QString>>", QUParameter::InOut }
    };
    static const QUMethod slot_44 = {"commitAttributeChanges", 4, param_slot_44 };
    static const QUParameter param_slot_45[] = {
	{ "p", &static_QUType_ptr, "QPainter", QUParameter::In },
	{ "viewExtent", &static_QUType_ptr, "QgsRect", QUParameter::In },
	{ "cXf", &static_QUType_ptr, "QgsMapToPixel", QUParameter::In },
	{ "dst", &static_QUType_ptr, "QPaintDevice", QUParameter::In },
	{ "widthScale", &static_QUType_double, 0, QUParameter::In },
	{ "symbolScale", &static_QUType_double, 0, QUParameter::In }
    };
    static const QUMethod slot_45 = {"draw", 6, param_slot_45 };
    static const QUParameter param_slot_46[] = {
	{ "p", &static_QUType_ptr, "QPainter", QUParameter::In },
	{ "viewExtent", &static_QUType_ptr, "QgsRect", QUParameter::In },
	{ "cXf", &static_QUType_ptr, "QgsMapToPixel", QUParameter::In },
	{ "dst", &static_QUType_ptr, "QPaintDevice", QUParameter::In },
	{ "widthScale", &static_QUType_double, 0, QUParameter::In },
	{ "symbolScale", &static_QUType_double, 0, QUParameter::In },
	{ "oversampling", &static_QUType_int, 0, QUParameter::In }
    };
    static const QUMethod slot_46 = {"draw", 7, param_slot_46 };
    static const QUParameter param_slot_47[] = {
	{ "p", &static_QUType_ptr, "QPainter", QUParameter::In },
	{ "viewExtent", &static_QUType_ptr, "QgsRect", QUParameter::In },
	{ "cXf", &static_QUType_ptr, "QgsMapToPixel", QUParameter::In },
	{ "dst", &static_QUType_ptr, "QPaintDevice", QUParameter::In },
	{ "scale", &static_QUType_double, 0, QUParameter::In }
    };
    static const QUMethod slot_47 = {"drawLabels", 5, param_slot_47 };
    static const QUMethod slot_48 = {"startEditing", 0, 0 };
    static const QUMethod slot_49 = {"stopEditing", 0, 0 };
    static const QMetaData slot_tbl[] = {
	{ "inOverview(bool)", &slot_0, QMetaData::Public },
	{ "invalidateTableDisplay()", &slot_1, QMetaData::Public },
	{ "select(int)", &slot_2, QMetaData::Public },
	{ "removeSelection()", &slot_3, QMetaData::Public },
	{ "triggerRepaint()", &slot_4, QMetaData::Public },
	{ "showLayerProperties()", &slot_5, QMetaData::Public },
	{ "renderer()", &slot_6, QMetaData::Public },
	{ "rendererDialog()", &slot_7, QMetaData::Public },
	{ "setRenderer(QgsRenderer*)", &slot_8, QMetaData::Public },
	{ "setRendererDialog(QDialog*)", &slot_9, QMetaData::Public },
	{ "setLayerProperties(QgsDlgVectorLayerProperties*)", &slot_10, QMetaData::Public },
	{ "vectorType()", &slot_11, QMetaData::Public },
	{ "propertiesDialog()", &slot_12, QMetaData::Public },
	{ "contextMenu()", &slot_13, QMetaData::Public },
	{ "bBoxOfSelected()", &slot_14, QMetaData::Public },
	{ "providerType()", &slot_15, QMetaData::Public },
	{ "isValid()", &slot_16, QMetaData::Public },
	{ "readXML_(QDomNode&)", &slot_17, QMetaData::Public },
	{ "writeXML_(QDomNode&,QDomDocument&)", &slot_18, QMetaData::Public },
	{ "getFirstFeature()", &slot_19, QMetaData::Public },
	{ "getFirstFeature(bool)", &slot_20, QMetaData::Public },
	{ "getNextFeature()", &slot_21, QMetaData::Public },
	{ "getNextFeature(bool)", &slot_22, QMetaData::Public },
	{ "getNextFeature(QgsFeature&)", &slot_23, QMetaData::Public },
	{ "getNextFeature(QgsFeature&,bool)", &slot_24, QMetaData::Public },
	{ "featureCount()", &slot_25, QMetaData::Public },
	{ "updateFeatureCount()", &slot_26, QMetaData::Public },
	{ "updateExtents()", &slot_27, QMetaData::Public },
	{ "setSubsetString(QString)", &slot_28, QMetaData::Public },
	{ "subsetString()", &slot_29, QMetaData::Public },
	{ "fieldCount()", &slot_30, QMetaData::Public },
	{ "fields()", &slot_31, QMetaData::Public },
	{ "addFeature(QgsFeature*)", &slot_32, QMetaData::Public },
	{ "deleteSelectedFeatures()", &slot_33, QMetaData::Public },
	{ "getDefaultValue(const QString&,QgsFeature*)", &slot_34, QMetaData::Public },
	{ "setLabelOn(bool)", &slot_35, QMetaData::Public },
	{ "labelOn()", &slot_36, QMetaData::Public },
	{ "minimumScale()", &slot_37, QMetaData::Public },
	{ "maximumScale()", &slot_38, QMetaData::Public },
	{ "scaleDependentRender()", &slot_39, QMetaData::Public },
	{ "isEditable()", &slot_40, QMetaData::Public },
	{ "isModified()", &slot_41, QMetaData::Public },
	{ "saveAsShapefile()", &slot_42, QMetaData::Public },
	{ "snapPoint(QgsPoint&,double)", &slot_43, QMetaData::Public },
	{ "commitAttributeChanges(const std::set<QString>&,const std::map<QString,QString>&,std::map<int,std::map<QString,QString>>&)", &slot_44, QMetaData::Public },
	{ "draw(QPainter*,QgsRect*,QgsMapToPixel*,QPaintDevice*,double,double)", &slot_45, QMetaData::Public },
	{ "draw(QPainter*,QgsRect*,QgsMapToPixel*,QPaintDevice*,double,double,int)", &slot_46, QMetaData::Public },
	{ "drawLabels(QPainter*,QgsRect*,QgsMapToPixel*,QPaintDevice*,double)", &slot_47, QMetaData::Public },
	{ "startEditing()", &slot_48, QMetaData::Protected },
	{ "stopEditing()", &slot_49, QMetaData::Protected }
    };
    static const QUParameter param_signal_0[] = {
	{ "norepaint", &static_QUType_bool, 0, QUParameter::In }
    };
    static const QUMethod signal_0 = {"editingStopped", 1, param_signal_0 };
    static const QMetaData signal_tbl[] = {
	{ "editingStopped(bool)", &signal_0, QMetaData::Public }
    };
    metaObj = QMetaObject::new_metaobject(
	"QgsVectorLayer", parentObject,
	slot_tbl, 50,
	signal_tbl, 1,
#ifndef QT_NO_PROPERTIES
	0, 0,
	0, 0,
#endif // QT_NO_PROPERTIES
	0, 0 );
    cleanUp_QgsVectorLayer.setMetaObject( metaObj );
    return metaObj;
}

void* QgsVectorLayer::qt_cast( const char* clname )
{
    if ( !qstrcmp( clname, "QgsVectorLayer" ) )
	return this;
    return QgsMapLayer::qt_cast( clname );
}

// SIGNAL editingStopped
void QgsVectorLayer::editingStopped( bool t0 )
{
    activate_signal_bool( staticMetaObject()->signalOffset() + 0, t0 );
}

bool QgsVectorLayer::qt_invoke( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->slotOffset() ) {
    case 0: inOverview((bool)static_QUType_bool.get(_o+1)); break;
    case 1: invalidateTableDisplay(); break;
    case 2: select((int)static_QUType_int.get(_o+1)); break;
    case 3: removeSelection(); break;
    case 4: triggerRepaint(); break;
    case 5: showLayerProperties(); break;
    case 6: static_QUType_ptr.set(_o,renderer()); break;
    case 7: static_QUType_ptr.set(_o,rendererDialog()); break;
    case 8: setRenderer((QgsRenderer*)static_QUType_ptr.get(_o+1)); break;
    case 9: setRendererDialog((QDialog*)static_QUType_ptr.get(_o+1)); break;
    case 10: setLayerProperties((QgsDlgVectorLayerProperties*)static_QUType_ptr.get(_o+1)); break;
    case 11: vectorType(); break;
    case 12: static_QUType_ptr.set(_o,propertiesDialog()); break;
    case 13: static_QUType_ptr.set(_o,contextMenu()); break;
    case 14: bBoxOfSelected(); break;
    case 15: static_QUType_QString.set(_o,providerType()); break;
    case 16: static_QUType_bool.set(_o,isValid()); break;
    case 17: static_QUType_bool.set(_o,readXML_((QDomNode&)*((QDomNode*)static_QUType_ptr.get(_o+1)))); break;
    case 18: static_QUType_bool.set(_o,writeXML_((QDomNode&)*((QDomNode*)static_QUType_ptr.get(_o+1)),(QDomDocument&)*((QDomDocument*)static_QUType_ptr.get(_o+2)))); break;
    case 19: static_QUType_ptr.set(_o,getFirstFeature()); break;
    case 20: static_QUType_ptr.set(_o,getFirstFeature((bool)static_QUType_bool.get(_o+1))); break;
    case 21: static_QUType_ptr.set(_o,getNextFeature()); break;
    case 22: static_QUType_ptr.set(_o,getNextFeature((bool)static_QUType_bool.get(_o+1))); break;
    case 23: static_QUType_bool.set(_o,getNextFeature((QgsFeature&)*((QgsFeature*)static_QUType_ptr.get(_o+1)))); break;
    case 24: static_QUType_bool.set(_o,getNextFeature((QgsFeature&)*((QgsFeature*)static_QUType_ptr.get(_o+1)),(bool)static_QUType_bool.get(_o+2))); break;
    case 25: featureCount(); break;
    case 26: updateFeatureCount(); break;
    case 27: updateExtents(); break;
    case 28: setSubsetString((QString)static_QUType_QString.get(_o+1)); break;
    case 29: static_QUType_QString.set(_o,subsetString()); break;
    case 30: static_QUType_int.set(_o,fieldCount()); break;
    case 31: fields(); break;
    case 32: static_QUType_bool.set(_o,addFeature((QgsFeature*)static_QUType_ptr.get(_o+1))); break;
    case 33: static_QUType_bool.set(_o,deleteSelectedFeatures()); break;
    case 34: static_QUType_QString.set(_o,getDefaultValue((const QString&)static_QUType_QString.get(_o+1),(QgsFeature*)static_QUType_ptr.get(_o+2))); break;
    case 35: setLabelOn((bool)static_QUType_bool.get(_o+1)); break;
    case 36: static_QUType_bool.set(_o,labelOn()); break;
    case 37: static_QUType_int.set(_o,minimumScale()); break;
    case 38: static_QUType_int.set(_o,maximumScale()); break;
    case 39: static_QUType_bool.set(_o,scaleDependentRender()); break;
    case 40: static_QUType_bool.set(_o,isEditable()); break;
    case 41: static_QUType_bool.set(_o,isModified()); break;
    case 42: saveAsShapefile(); break;
    case 43: static_QUType_bool.set(_o,snapPoint((QgsPoint&)*((QgsPoint*)static_QUType_ptr.get(_o+1)),(double)static_QUType_double.get(_o+2))); break;
    case 44: static_QUType_bool.set(_o,commitAttributeChanges((const std::set<QString>&)*((const std::set<QString>*)static_QUType_ptr.get(_o+1)),(const std::map<QString,QString>&)*((const std::map<QString,QString>*)static_QUType_ptr.get(_o+2)),(std::map<int,std::map<QString,QString> >&)*((std::map<int,std::map<QString,QString> >*)static_QUType_ptr.get(_o+3)))); break;
    case 45: draw((QPainter*)static_QUType_ptr.get(_o+1),(QgsRect*)static_QUType_ptr.get(_o+2),(QgsMapToPixel*)static_QUType_ptr.get(_o+3),(QPaintDevice*)static_QUType_ptr.get(_o+4),(double)static_QUType_double.get(_o+5),(double)static_QUType_double.get(_o+6)); break;
    case 46: draw((QPainter*)static_QUType_ptr.get(_o+1),(QgsRect*)static_QUType_ptr.get(_o+2),(QgsMapToPixel*)static_QUType_ptr.get(_o+3),(QPaintDevice*)static_QUType_ptr.get(_o+4),(double)static_QUType_double.get(_o+5),(double)static_QUType_double.get(_o+6),(int)static_QUType_int.get(_o+7)); break;
    case 47: drawLabels((QPainter*)static_QUType_ptr.get(_o+1),(QgsRect*)static_QUType_ptr.get(_o+2),(QgsMapToPixel*)static_QUType_ptr.get(_o+3),(QPaintDevice*)static_QUType_ptr.get(_o+4),(double)static_QUType_double.get(_o+5)); break;
    case 48: startEditing(); break;
    case 49: stopEditing(); break;
    default:
	return QgsMapLayer::qt_invoke( _id, _o );
    }
    return TRUE;
}

bool QgsVectorLayer::qt_emit( int _id, QUObject* _o )
{
    switch ( _id - staticMetaObject()->signalOffset() ) {
    case 0: editingStopped((bool)static_QUType_bool.get(_o+1)); break;
    default:
	return QgsMapLayer::qt_emit(_id,_o);
    }
    return TRUE;
}
#ifndef QT_NO_PROPERTIES

bool QgsVectorLayer::qt_property( int id, int f, QVariant* v)
{
    return QgsMapLayer::qt_property( id, f, v);
}

bool QgsVectorLayer::qt_static_property( QObject* , int , int , QVariant* ){ return FALSE; }
#endif // QT_NO_PROPERTIES
